==> haskell-hsyaml-aeson-0.2.0.0-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HsYAML-aeson
version:              0.2.0.0
visibility:           public
id:                   HsYAML-aeson-0.2.0.0-IPNTIhnaR8B277SduGWp79
key:                  HsYAML-aeson-0.2.0.0-IPNTIhnaR8B277SduGWp79
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  3fb01847a9515ba77d8ff6fafb017016
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-8.10.4/site-local/HsYAML-aeson-0.2.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/HsYAML-aeson-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/HsYAML-aeson-0.2.0.0
hs-libraries:         HSHsYAML-aeson-0.2.0.0-IPNTIhnaR8B277SduGWp79
depends:
    HsYAML-0.2.1.0-AAgDglgdlMKLygB9OeDpfK
    aeson-1.5.6.0-AbTDFQXjdUODhV2zVRkDXT base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1 mtl-2.2.2
    scientific-0.3.6.2-gWLiwejpFQI84j5y9KlyG text-1.2.4.1
    unordered-containers-0.2.13.0-8xrAhv2QGcsF4IHfxyp1m2
    vector-0.12.2.0-Fhpcj4oaE8d6h7vKPBvHg3

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsyaml-aeson-0.2.0.0-145-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HsYAML-aeson
version:              0.2.0.0
visibility:           public
id:                   HsYAML-aeson-0.2.0.0-IplMqkmFj6qDYGAM875czm
key:                  HsYAML-aeson-0.2.0.0-IplMqkmFj6qDYGAM875czm
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  cc2452dc96006e55aeda735f0c4df7d9
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-8.10.4/site-local/HsYAML-aeson-0.2.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/HsYAML-aeson-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/HsYAML-aeson-0.2.0.0
hs-libraries:         HSHsYAML-aeson-0.2.0.0-IplMqkmFj6qDYGAM875czm
depends:
    HsYAML-0.2.1.0-Hnunp6l85B0Djpr4U2gmZn
    aeson-1.5.6.0-1F4wJcYByqDF2zyvzlYTcu base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1 mtl-2.2.2
    scientific-0.3.6.2-6Lqab90XKbP3SEh7juBnko text-1.2.4.1
    unordered-containers-0.2.13.0-HbayT3cnPyF1l0SwMwTqq2
    vector-0.12.2.0-95IX5pRBJ9d1AshkFlsixP

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
